@@ -36,7 +36,7 @@ static int curtype;			/* current HDU type  */
 *
 *******************************************************************************/
 /* routine to verify individual fitsfile */
-void verify_fits(char *infile, FILE *out)
+int verify_fits(char *infile, FILE *out)
 {
     char rootnam[FLEN_FILENAME] = "";   /* Input Fits file root name */
     fitsfile *infits;                   /* input fits file pointer */
@@ -56,7 +56,7 @@ void verify_fits(char *infile, FILE *out)
     pfile = p;
     p += (len -1);
     for (i = len - 1; i >= 0 && isspace((int)*p); i--) {*p = '\0'; p--;}
-    if(!strlen(pfile)) return;
+    if(!strlen(pfile)) return status;
 
 #ifndef WEBTOOL
     wrtout(out," ");
@@ -70,20 +70,23 @@ void verify_fits(char *infile, FILE *out)
     if(ffrtnm(pfile, rootnam, &status)) {
         wrtserr(out,"",&status,2);
         leave_early(out);
-        return;
+        status = 1;
+        return status;
     }
 
     if(fits_open_file(&infits, rootnam, READONLY, &status)) {
         wrtserr(out,"",&status,2);
         leave_early(out);
-        return;
+        status = 1;
+        return status;
     }
 
     /* get the total hdus */
     if(fits_get_num_hdus(infits, &totalhdu, &status)) {
         wrtserr(out,"",&status,2);
         leave_early(out);
-        return;
+        status = 1;
+        return status;
     }
 
     /* initialize the report */
@@ -135,6 +138,8 @@ void verify_fits(char *infile, FILE *out)
 
     /* close the input fitsfile  */
     fits_close_file(infits, &status);
+
+    return status;
 }
 
 void leave_early (FILE* out)
@@ -1826,6 +1831,7 @@ void test_tbl(fitsfile *infits, 	/* input fits file   */
                     strchr(tform[i],'M') == NULL &&   
                     strchr(tform[i],'I') == NULL &&  
                     strchr(tform[i],'J') == NULL &&  
+                    strchr(tform[i],'K') == NULL &&  
                     strchr(tform[i],'B') == NULL &&  
                     strchr(tform[i],'X') == NULL  ){ 
                      sprintf(errmes,
@@ -1870,6 +1876,7 @@ void test_tbl(fitsfile *infits, 	/* input fits file   */
                     strchr(tform[i],'M') == NULL &&   
                     strchr(tform[i],'I') == NULL &&  
                     strchr(tform[i],'J') == NULL &&  
+                    strchr(tform[i],'K') == NULL &&  
                     strchr(tform[i],'B') == NULL &&  
                     strchr(tform[i],'X') == NULL  ){ 
                      sprintf(errmes,
